ipecharts.option.seriesitems.scatter3d module
=============================================

.. automodule:: ipecharts.option.seriesitems.scatter3d
   :members:
   :show-inheritance:
   :undoc-members:
